==> sogo_3.2.6.orig.tar.gz: SOGo-3.2.6/SoObjects/Appointments/iCalEventChanges+SOGo.m <==
/* iCalEventChanges+SOGo.m - this file is part of SOGo
 *
 * Copyright (C) 2007-2010 Inverse inc.
 *
 * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
 *
 * This file is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#import <Foundation/NSArray.h>
#import <Foundation/NSString.h>

#import "iCalEventChanges+SOGo.h"

@implementation iCalEventChanges (SOGoExtensions)

- (BOOL) sequenceShouldBeIncreased
{
  static NSString *properties[] = {@"organizer", @"startDate", @"endDate",
                                   @"due", @"duration",
                                   @"rdate", @"rrule", @"exdate", @"exrule",
                                   @"status", @"location",
                                   nil};
  NSString **currentProperty;
  BOOL updateRequired;

  updateRequired = NO;

  currentProperty = properties;
  while (!updateRequired && *currentProperty)
    if ([updatedProperties containsObject: *currentProperty])
      updateRequired = YES;
    else
      currentProperty++;

  return updateRequired;
}

@end

==> sogo_5.5.1.orig.tar.gz: SOGo-5.5.1/SoObjects/Appointments/iCalEventChanges+SOGo.m <==
/* iCalEventChanges+SOGo.m - this file is part of SOGo
 *
 * Copyright (C) 2007-2019 Inverse inc.
 *
 * This file is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#import <Foundation/NSArray.h>
#import <Foundation/NSString.h>

#import "iCalEventChanges+SOGo.h"

@implementation iCalEventChanges (SOGoExtensions)

- (BOOL) sequenceShouldBeIncreased
{
  static NSString *properties[] = {@"organizer", @"startDate", @"endDate",
                                   @"due", @"duration", @"summary",
                                   @"rdate", @"rrule", @"exdate", @"exrule",
                                   @"status", @"location",
                                   nil};
  NSString **currentProperty;
  BOOL updateRequired;

  updateRequired = NO;

  currentProperty = properties;
  while (!updateRequired && *currentProperty)
    if ([updatedProperties containsObject: *currentProperty])
      updateRequired = YES;
    else
      currentProperty++;

  return updateRequired;
}

@end
